Skip to contents

Creates a sample CSV (or Excel) with columns for authors, affiliations, acknowledgments, conflicts, etc.

Usage

generate_template(file = "authordown_template.csv", excel = FALSE)

Arguments

file

A file path where the template should be written. Defaults to \"authordown_template.csv\" in the current directory.

excel

Logical. If TRUE, writes an Excel file (.xlsx) instead of CSV.

Value

Invisibly returns the data frame used for the template.

Examples

if (FALSE) { # \dontrun{
generate_template() # writes authordown_template.csv
} # }